@@ -71,6 +71,12 @@ class AccessLogConfig(AbstractModel):
         :type Encoding: str
         :param Format: 日志格式
         :type Format: str
+        :param Address: GRPC第三方服务器地址
+        :type Address: str
+        :param EnableServer: 是否启用GRPC第三方服务器
+        :type EnableServer: bool
+        :param EnableStdout: 是否启用标准输出
+        :type EnableStdout: bool
         """
         self.Enable = None
         self.Template = None
@@ -78,6 +84,9 @@ class AccessLogConfig(AbstractModel):
         self.CLS = None
         self.Encoding = None
         self.Format = None
+        self.Address = None
+        self.EnableServer = None
+        self.EnableStdout = None
 
 
     def _deserialize(self, params):
@@ -91,6 +100,9 @@ class AccessLogConfig(AbstractModel):
             self.CLS._deserialize(params.get("CLS"))
         self.Encoding = params.get("Encoding")
         self.Format = params.get("Format")
+        self.Address = params.get("Address")
+        self.EnableServer = params.get("EnableServer")
+        self.EnableStdout = params.get("EnableStdout")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -226,6 +238,8 @@ class Cluster(AbstractModel):
 - TKE
 - EKS
         :type Type: str
+        :param HostedNamespaces: 集群关联的 Namespace 列表
+        :type HostedNamespaces: list of str
         """
         self.ClusterId = None
         self.Region = None
@@ -238,6 +252,7 @@ class Cluster(AbstractModel):
         self.Config = None
         self.Status = None
         self.Type = None
+        self.HostedNamespaces = None
 
 
     def _deserialize(self, params):
@@ -256,6 +271,7 @@ class Cluster(AbstractModel):
             self.Status = ClusterStatus()
             self.Status._deserialize(params.get("Status"))
         self.Type = params.get("Type")
+        self.HostedNamespaces = params.get("HostedNamespaces")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -363,6 +379,50 @@ class ClusterStatus(AbstractModel):
         
 
 
+class CustomPromConfig(AbstractModel):
+    """第三方 Prometheus 配置参数
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Url: Prometheus 访问地址
+        :type Url: str
+        :param AuthType: 认证方式
+        :type AuthType: str
+        :param IsPublicAddr: 是否公网地址，缺省为 false
+        :type IsPublicAddr: bool
+        :param VpcId: 虚拟网络id
+        :type VpcId: str
+        :param Username: Prometheus 用户名（用于 basic 认证方式）
+        :type Username: str
+        :param Password: Prometheus 密码（用于 basic 认证方式）
+        :type Password: str
+        """
+        self.Url = None
+        self.AuthType = None
+        self.IsPublicAddr = None
+        self.VpcId = None
+        self.Username = None
+        self.Password = None
+
+
+    def _deserialize(self, params):
+        self.Url = params.get("Url")
+        self.AuthType = params.get("AuthType")
+        self.IsPublicAddr = params.get("IsPublicAddr")
+        self.VpcId = params.get("VpcId")
+        self.Username = params.get("Username")
+        self.Password = params.get("Password")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class DeployConfig(AbstractModel):
     """部署配置
 
@@ -542,6 +602,76 @@ class EgressGateway(AbstractModel):
         
 
 
+class ExtensiveCluster(AbstractModel):
+    """内网独占集群配置
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterId: Cluster ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ClusterId: str
+        :param Zone: 可用区
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Zone: str
+        """
+        self.ClusterId = None
+        self.Zone = None
+
+
+    def _deserialize(self, params):
+        self.ClusterId = params.get("ClusterId")
+        self.Zone = params.get("Zone")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ExtensiveClusters(AbstractModel):
+    """内网独占集群配置列表
+
+    """
+
+    def __init__(self):
+        r"""
+        :param L4Clusters: 4层集群配置
+注意：此字段可能返回 null，表示取不到有效值。
+        :type L4Clusters: list of ExtensiveCluster
+        :param L7Clusters: 7层集群配置
+注意：此字段可能返回 null，表示取不到有效值。
+        :type L7Clusters: list of ExtensiveCluster
+        """
+        self.L4Clusters = None
+        self.L7Clusters = None
+
+
+    def _deserialize(self, params):
+        if params.get("L4Clusters") is not None:
+            self.L4Clusters = []
+            for item in params.get("L4Clusters"):
+                obj = ExtensiveCluster()
+                obj._deserialize(item)
+                self.L4Clusters.append(obj)
+        if params.get("L7Clusters") is not None:
+            self.L7Clusters = []
+            for item in params.get("L7Clusters"):
+                obj = ExtensiveCluster()
+                obj._deserialize(item)
+                self.L7Clusters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Filter(AbstractModel):
     """键值对过滤器，用于条件过滤查询。例如过滤ID、名称等
 
@@ -848,13 +978,37 @@ OPEN：公网属性， INTERNAL：内网属性。
         :type SubnetId: str
         :param InternetChargeType: TRAFFIC_POSTPAID_BY_HOUR 按流量按小时后计费 ; BANDWIDTH_POSTPAID_BY_HOUR 按带宽按小时后计费;只读。
         :type InternetChargeType: str
-        :param InternetMaxBandwidthOut: 最大出带宽，单位Mbps，范围支持0到2048，仅对公网属性的LB生效，默认值 10
+        :param InternetMaxBandwidthOut: 最大出带宽，单位Mbps，仅对公网属性的LB生效，默认值 10
         :type InternetMaxBandwidthOut: int
+        :param ZoneID: 可用区 ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ZoneID: str
+        :param VipIsp: 运营商类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VipIsp: str
+        :param TgwGroupName: TGW Group 名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TgwGroupName: str
+        :param AddressIPVersion: IP 类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AddressIPVersion: str
+        :param Tags: 标签列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Tags: list of Tag
+        :param ExtensiveClusters: 内网独占集群配置列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExtensiveClusters: :class:`tencentcloud.tcm.v20210413.models.ExtensiveClusters`
         """
         self.LoadBalancerType = None
         self.SubnetId = None
         self.InternetChargeType = None
         self.InternetMaxBandwidthOut = None
+        self.ZoneID = None
+        self.VipIsp = None
+        self.TgwGroupName = None
+        self.AddressIPVersion = None
+        self.Tags = None
+        self.ExtensiveClusters = None
 
 
     def _deserialize(self, params):
@@ -862,6 +1016,19 @@ OPEN：公网属性， INTERNAL：内网属性。
         self.SubnetId = params.get("SubnetId")
         self.InternetChargeType = params.get("InternetChargeType")
         self.InternetMaxBandwidthOut = params.get("InternetMaxBandwidthOut")
+        self.ZoneID = params.get("ZoneID")
+        self.VipIsp = params.get("VipIsp")
+        self.TgwGroupName = params.get("TgwGroupName")
+        self.AddressIPVersion = params.get("AddressIPVersion")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
+        if params.get("ExtensiveClusters") is not None:
+            self.ExtensiveClusters = ExtensiveClusters()
+            self.ExtensiveClusters._deserialize(params.get("ExtensiveClusters"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1190,11 +1357,15 @@ class PrometheusConfig(AbstractModel):
         :type Region: str
         :param InstanceId: 关联已存在实例Id，不填则默认创建
         :type InstanceId: str
+        :param CustomProm: 第三方 Prometheus
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CustomProm: :class:`tencentcloud.tcm.v20210413.models.CustomPromConfig`
         """
         self.VpcId = None
         self.SubnetId = None
         self.Region = None
         self.InstanceId = None
+        self.CustomProm = None
 
 
     def _deserialize(self, params):
@@ -1202,6 +1373,9 @@ class PrometheusConfig(AbstractModel):
         self.SubnetId = params.get("SubnetId")
         self.Region = params.get("Region")
         self.InstanceId = params.get("InstanceId")
+        if params.get("CustomProm") is not None:
+            self.CustomProm = CustomPromConfig()
+            self.CustomProm._deserialize(params.get("CustomProm"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1466,6 +1640,38 @@ class Service(AbstractModel):
         
 
 
+class Tag(AbstractModel):
+    """标签
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Key: 标签键
+        :type Key: str
+        :param Value: 标签值
+        :type Value: str
+        :param Passthrough: 是否透传给其他关联产品
+        :type Passthrough: bool
+        """
+        self.Key = None
+        self.Value = None
+        self.Passthrough = None
+
+
+    def _deserialize(self, params):
+        self.Key = params.get("Key")
+        self.Value = params.get("Value")
+        self.Passthrough = params.get("Passthrough")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class TracingConfig(AbstractModel):
     """调用链配置
 
@@ -1479,10 +1685,13 @@ class TracingConfig(AbstractModel):
         :type Enable: bool
         :param APM: 腾讯云 APM 服务相关参数
         :type APM: :class:`tencentcloud.tcm.v20210413.models.APM`
+        :param Zipkin: 启动第三方服务器的地址
+        :type Zipkin: :class:`tencentcloud.tcm.v20210413.models.TracingZipkin`
         """
         self.Sampling = None
         self.Enable = None
         self.APM = None
+        self.Zipkin = None
 
 
     def _deserialize(self, params):
@@ -1491,6 +1700,33 @@ class TracingConfig(AbstractModel):
         if params.get("APM") is not None:
             self.APM = APM()
             self.APM._deserialize(params.get("APM"))
+        if params.get("Zipkin") is not None:
+            self.Zipkin = TracingZipkin()
+            self.Zipkin._deserialize(params.get("Zipkin"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class TracingZipkin(AbstractModel):
+    """调用追踪的Zipkin设置
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Address: Zipkin调用地址
+        :type Address: str
+        """
+        self.Address = None
+
+
+    def _deserialize(self, params):
+        self.Address = params.get("Address")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1515,11 +1751,18 @@ class WorkloadConfig(AbstractModel):
         :type HorizontalPodAutoscaler: :class:`tencentcloud.tcm.v20210413.models.HorizontalPodAutoscalerSpec`
         :param SelectedNodeList: 部署到指定节点
         :type SelectedNodeList: list of str
+        :param DeployMode: 组件的部署模式，取值说明：
+IN_GENERAL_NODE：常规节点
+IN_EKLET：eklet 节点
+IN_SHARED_NODE_POOL：共享节电池
+IN_EXCLUSIVE_NODE_POOL：独占节点池
+        :type DeployMode: str
         """
         self.Replicas = None
         self.Resources = None
         self.HorizontalPodAutoscaler = None
         self.SelectedNodeList = None
+        self.DeployMode = None
 
 
     def _deserialize(self, params):
@@ -1531,6 +1774,7 @@ class WorkloadConfig(AbstractModel):
             self.HorizontalPodAutoscaler = HorizontalPodAutoscalerSpec()
             self.HorizontalPodAutoscaler._deserialize(params.get("HorizontalPodAutoscaler"))
         self.SelectedNodeList = params.get("SelectedNodeList")
+        self.DeployMode = params.get("DeployMode")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
